<?php

namespace App\Http\Controllers;

use App\Http\Requests\EmployeesRequest;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class EmployeesController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = User::all();
        $numb = 1;
        return view('admin.pages.employees.data', compact('data', 'numb'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.employees.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(EmployeesRequest $request)
    {
        $data = $request->all();
        $data['photos'] = $request->file('photos')->store('assets/employees', 'public');
        User::create($data);
        return redirect()->route('employees.index')->with('success', 'Data added successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(User $employees)
    {

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $employees = User::find($id);
        return view('admin.pages.employees.edit', compact('employees'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(EmployeesRequest $request, $id)
    {
        $data = $request->all();
        $employees = User::find($id);
        if ($request->file('photos')) {
            if (Storage::disk('public')->exists($employees->photos)) {
                Storage::disk('public')->delete($employees->photos);
            }
            $data['photos'] = $request->file('photos')->store('assets/employees', 'public');
        }
        $employees->update($data);
        return redirect()->route('employees.index')->with('success', 'Data updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(User $employee)
    {
        if (Storage::disk('public')->exists($employee->photos)) {
            Storage::disk('public')->delete($employee->photos);
        }
        $employee->delete();

        return redirect()->back()->with('success', 'Data deleted successfully');
    }
}
